@@ -1,12 +1,21 @@
-from django.http import HttpResponse
+import json
+from django.http import HttpResponse, HttpRequest
 from django.middleware.csrf import CsrfViewMiddleware
 
-from rhetoric.view import ViewCallback
-from rhetoric.request import JsonBodyProperty
+from .view import ViewCallback
+from .compat import text_
 
 
 class CsrfProtectedViewDispatchMiddleware(CsrfViewMiddleware):
 
+    def __init__(self):
+        super(CsrfProtectedViewDispatchMiddleware, self).__init__()
+        self.add_property(
+            HttpRequest,
+            'json_body',
+            lambda request: json.loads(text_(request.read(), request.encoding or 'utf-8'))
+        )
+
     def process_request(self, request):
         # We assume here that CsrfViewMiddleware doesn't have the process_request method
         # which should be called via super().
@@ -14,7 +23,6 @@ class CsrfProtectedViewDispatchMiddleware(CsrfViewMiddleware):
         # set request.response object as in
         # http://docs.pylonsproject.org/projects/pyramid/en/latest/api/request.html#pyramid.request.Request.response
         setattr(request, 'response', HttpResponse())
-        setattr(request, 'json_body', JsonBodyProperty(request))
 
 
     def process_view(self, request, callback, callback_args, callback_kwargs):
@@ -29,3 +37,7 @@ class CsrfProtectedViewDispatchMiddleware(CsrfViewMiddleware):
         return super(CsrfProtectedViewDispatchMiddleware, self).process_view(
             request, callback, callback_args, callback_kwargs
         )
+
+    def add_property(self, cls, name, method):
+        if not hasattr(cls, name):
+            setattr(cls, name, property(method))
\ No newline at end of file
