@@ -104,4 +104,12 @@ class DashboardAPIv2(object):
         return {
             'version': 2,
             'method': 'POST'
-        }
\ No newline at end of file
+        }
+
+@view_config(route_name='index.json_body', request_method='POST', renderer='json')
+def json_body(request):
+    data = request.json_body
+    if data:
+        if 'key' in data:
+            return {'result': 'key'}
+    return {'result': 'no-key'}
